#!/usr/bin/env python

"""
Extract tagged sentences from an XML file in the SMULTRON treebank format.
Prints them to stdout, one per line, space-separated, with tags separated by a
slash.
"""

import sys, string
from xml.sax import handler, make_parser

class SentenceExtractor(handler.ContentHandler):
    def __init__(self, outfile):
        self.outfile = outfile
        self.cursentence = []
        self.sentences = []

    def startElement(self, name, attrs):
        if name == "terminals":
            self.cursentence = []

        if name == "t":
            word = (attrs.get("word")).replace("/","")
            pos = attrs.get("pos")
            taggedword = word + "/" + pos
            self.cursentence.append(taggedword)
            # self.cursentence.append(word)

    def endElement(self, name):
        if name == "terminals":
            if(len(self.cursentence) <= 15):
                self.sentences.append(self.cursentence)

def extract(inFileName):
    outFile = sys.stdout
    handler = SentenceExtractor(outFile)
    parser = make_parser()
    parser.setContentHandler(handler)
    parser.parse(inFileName)

    for sentence in handler.sentences:
        print " ".join(sentence)

def main():
    args = sys.argv[1:]
    if len(args) != 1:
        print 'usage: python extractsentences.py infile.xml'
        sys.exit(-1)
    extract(args[0])

if __name__ == '__main__':
    main()
