#!/usr/bin/env python

from nltk.grammar import Nonterminal

def replacepunctuation(text):
    """NLTK doesn't like punctuation in names of nonterminals. So we'll replace
    those."""
    text = text.replace("--", "DASH")
    text = text.replace(",", "COMMA")
    text = text.replace(":", "COLON")
    text = text.replace(".", "PERIOD")
    text = text.replace("''", "QUOTE")
    text = text.replace("-", "DASH")
    text = text.replace("$", "BLING")
    return text

def production_sort(left, right):
    TOP = Nonterminal("TOP")
    if left.lhs() == TOP and right.lhs() != TOP:
        return -1
    if right.lhs() == TOP and left.lhs() != TOP:
        return 1

    # if "'" in str(left.rhs()) and "'" not in str(right.rhs()):
    #     return 1
    # if "'" in str(right.rhs()) and "'" not in str(left.rhs()):
    #     return -1 

    if str(left.lhs()) != str(right.lhs()):
        return cmp(str(left.lhs()), str(right.lhs()))
    else:
        return cmp(str(left.rhs()), str(right.rhs()))

def only_tag(tagged):
    """Takes a tagged token of the form word/tag and returns just the tag. Also
    replaces the literal tag with one where the punctuation has been replaced
    with a word, for ease of parsing with NLTK."""

    assert "/" in tagged
    return replacepunctuation(tagged.split("/")[1])

def only_word(tagged):
    """Ibid."""
    assert "/" in tagged
    return tagged.split("/")[0]

def normalize(numbers):
    """Given a list of numbers, scale them so they add up to 1.0"""
    total = sum(numbers)
    assert total > 0.0
    scalefactor = 1.0 / total
    scale = lambda x: (x * scalefactor)
    return map(scale, numbers)
